==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/client/render/feature/IceSkateFeatureRenderer.java <==
package com.github.thedeathlycow.frostiful.client.render.feature;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.client.model.IceSkateModel;
import com.github.thedeathlycow.frostiful.registry.tag.FItemTags;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_572;

public class IceSkateFeatureRenderer<
        T extends class_1309,
        M extends class_572<T>,
        I extends IceSkateModel<T>
        > extends class_3887<T, M> {

    private final I model;

    private static final class_2960 SKATE_TEXTURE = Frostiful.id("textures/entity/skates.png");

    public IceSkateFeatureRenderer(
            class_3883<T, M> context,
            I model
    ) {
        super(context);
        this.model = model;
    }


    @Override
    public void render(
            class_4587 matrices,
            class_4597 vertexConsumers,
            int light,
            T entity,
            float limbAngle, float limbDistance,
            float tickDelta, float animationProgress,
            float headYaw, float headPitch
    ) {
        if (entity.method_6118(class_1304.field_6166).method_31573(FItemTags.ICE_SKATES)) {
            this.method_17165().method_2818(model);
            class_4588 vertexConsumer = vertexConsumers.getBuffer(class_1921.method_25448(SKATE_TEXTURE));
            this.model.method_60879(matrices, vertexConsumer, light, class_4608.field_21444);
        }
    }
}

==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/client/render/feature/IceSkateFeatureRenderer.java <==
package com.github.thedeathlycow.frostiful.client.render.feature;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.client.render.model.IceSkateModel;
import com.github.thedeathlycow.frostiful.client.render.state.FBipedRenderState;
import net.minecraft.class_10034;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_572;

public class IceSkateFeatureRenderer<
        S extends class_10034,
        M extends class_572<S>,
        I extends IceSkateModel<S>
        > extends class_3887<S, M> {
    private final I model;

    private static final class_2960 SKATE_TEXTURE = Frostiful.id("textures/entity/skates.png");

    public IceSkateFeatureRenderer(
            class_3883<S, M> context,
            I model
    ) {
        super(context);
        this.model = model;
    }

    @Override
    public void render(
            class_4587 matrices,
            class_4597 vertexConsumers,
            int light,
            S state,
            float limbAngle,
            float limbDistance
    ) {
        if (((FBipedRenderState) state).frostiful$wearingIceSkates()) {
            this.method_17165().method_64254(model);
            class_4588 vertexConsumer = vertexConsumers.getBuffer(class_1921.method_25448(SKATE_TEXTURE));
            this.model.method_60879(matrices, vertexConsumer, light, class_4608.field_21444);
        }
    }
}
